
soft-collect
============



|PyPI|  |Black| |pre-commit|

.. |PyPI| image:: https://img.shields.io/pypi/v/soft-collect.svg
   :target: https://pypi.org/project/soft-collect/
   :alt: PyPI
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit


Features
--------

* TODO


Requirements
------------

* TODO


Installation
------------

You can install *soft-collect* via pip_ from PyPI_:

.. code:: console

   $ pip install soft-collect


Usage
-----

* TODO



.. _PyPI: https://pypi.org/
.. _pip: https://pip.pypa.io/
